@@ -1,5 +1,7 @@
 mod from_closure;
+mod from_function;
 mod to_closure;
 
 pub use from_closure::*;
+pub use from_function::*;
 pub use to_closure::*;
